==> marketing_plugin-0.0.1.tar.gz: lib/plugin_codelab_method_channel.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'plugin_codelab_platform_interface.dart';

/// An implementation of [PluginCodelabPlatform] that uses method channels.
class MethodChannelPluginCodelab extends PluginCodelabPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final platform = const MethodChannel('ads');

  @override
  Future callAppOpenAds() async {
    try {
      await platform.invokeMethod('Adopen');
      return true;
    } on PlatformException catch (e) {
      if (kDebugMode) {
        print("Failed to get battery level: '${e.message}'.");
      }
      return true;
    }
  }

  @override
  Future getCallInterstitialAds() async {
    try {
      await platform.invokeMethod('Interstitial');
      return true;
    } on PlatformException catch (e) {
      if (kDebugMode) {
        print("Failed to get battery level: '${e.message}'.");
      }
      return true;
    }
  }

  @override
  Future getCallCloseInterstitialAds() async {
    try {
      await platform.invokeMethod('CloseInterstitial');
      return true;
    } on PlatformException catch (e) {
      if (kDebugMode) {
        print("Failed to get battery level: '${e.message}'.");
      }
      return true;
    }
  }

  @override
  Future adsONorOFf() async {
    bool isAd = false;
    try {
      var result = await platform.invokeMethod('isAD');
      
      isAd = result;
    } on PlatformException catch (e) {
      isAd = false;
    }
    return isAd;
  }

  @override
  Future dummyScreen() async {
    bool dummyScreen = false;
    try {
      var result = await platform.invokeMethod('dummyScreen');
      
      dummyScreen = result;
    } on PlatformException catch (e) {
      dummyScreen = false;
    }
    return dummyScreen;
  }

  @override
  Future quiz() async {
    var quiz = {};
    try {
      var result = await platform.invokeMethod('isQuizeAd');
      quiz['isQuizeAd'] = result;
    } on PlatformException catch (e) {}
    try {
      var result1 = await platform.invokeMethod('quiz');
      quiz['quizUrl'] = result1;
    } on PlatformException catch (e) {}
    return quiz;
  }

  @override
  Future onesignalKey() async {
    try {
      var result = await platform.invokeMethod('onesignalKey');
      
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future privacyPolicy() async {
    try {
      var result = await platform.invokeMethod('privacyPolicy');
      
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future lottiurl() async {
    try {
      var result = await platform.invokeMethod('loaderUrl');
      
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future issdkads() async {
    try {
      var result = await platform.invokeMethod('issdkads');
      
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future FBbannerAd() async {
    try {
      var result = await platform.invokeMethod('FBbannerAd');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future FBrewardedAd() async {
    try {
      var result = await platform.invokeMethod('FBrewardedAd');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future FBinterstitialAd() async {
    try {
      var result = await platform.invokeMethod('FBinterstitialAd');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future FBnativeAd() async {
    try {
      var result = await platform.invokeMethod('FBnativeAd');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future showreward() async {
    try {
      var result = await platform.invokeMethod('showreward');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future isEveryads() async {
    try {
      var result = await platform.invokeMethod('isEveryads');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future isBackgroudAds() async {
    try {
      var result = await platform.invokeMethod('isBackgroudAds');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future colors() async {
    try {
      var result = await platform.invokeMethod('colors');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future adManagerIds() async {
    try {
      var result = await platform.invokeMethod('adManagerIds');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future isfacebookads() async {
    try {
      var result = await platform.invokeMethod('isfacebookads');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future isCustomeads() async {
    try {
      var result = await platform.invokeMethod('isCustomeads');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }

  @override
  Future isnativead() async {
    try {
      var result = await platform.invokeMethod('isnativead');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }@override
  Future isrecycleAds() async {
    try {
      var result = await platform.invokeMethod('isrecycleAds');
      return result;
    } on PlatformException catch (e) {
      return '';
    }
  }
}

==> marketing_plugin-0.0.9.tar.gz: lib/plugin_codelab_method_channel.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'plugin_codelab_platform_interface.dart';

/// An implementation of [PluginCodelabPlatform] that uses method channels.
class MethodChannelPluginCodelab extends PluginCodelabPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final platform = const MethodChannel('ads');

  @override
  Future callAppOpenAds() async {
    try {
      await platform.invokeMethod('Adopen');
      return true;
    } on PlatformException catch (e) {
      if (kDebugMode) {
        print("Failed to get battery level: '${e.message}'.");
      }
      return true;
    }
  }

  @override
  Future getCallInterstitialAds() async {
    try {
      await platform.invokeMethod('Interstitial');
      return true;
    } on PlatformException catch (e) {
      if (kDebugMode) {
        print("Failed to get battery level: '${e.message}'.");
      }
      return true;
    }
  }

  @override
  Future getCallCloseInterstitialAds() async {
    try {
      await platform.invokeMethod('CloseInterstitial');
      return true;
    } on PlatformException catch (e) {
      if (kDebugMode) {
        print("Failed to get battery level: '${e.message}'.");
      }
      return true;
    }
  }

  @override
  Future adsONorOFf() async {
    bool isAd = false;
    try {
      var result = await platform.invokeMethod('isAD');
      
      isAd = result;
    } on PlatformException {
      isAd = false;
    }
    return isAd;
  }

  @override
  Future dummyScreen() async {
    bool dummyScreen = false;
    try {
      var result = await platform.invokeMethod('dummyScreen');
      
      dummyScreen = result;
    } on PlatformException {
      dummyScreen = false;
    }
    return dummyScreen;
  }

  @override
  Future quiz() async {
    var quiz = {};
    try {
      var result = await platform.invokeMethod('isQuizeAd');
      quiz['isQuizeAd'] = result;
    } on PlatformException {}
    try {
      var result1 = await platform.invokeMethod('quiz');
      quiz['quizUrl'] = result1;
    } on PlatformException {}
    return quiz;
  }

  @override
  Future onesignalKey() async {
    try {
      var result = await platform.invokeMethod('onesignalKey');
      
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future privacyPolicy() async {
    try {
      var result = await platform.invokeMethod('privacyPolicy');
      
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future lottiurl() async {
    try {
      var result = await platform.invokeMethod('loaderUrl');
      
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future issdkads() async {
    try {
      var result = await platform.invokeMethod('issdkads');
      
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future FBbannerAd() async {
    try {
      var result = await platform.invokeMethod('FBbannerAd');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future FBrewardedAd() async {
    try {
      var result = await platform.invokeMethod('FBrewardedAd');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future FBinterstitialAd() async {
    try {
      var result = await platform.invokeMethod('FBinterstitialAd');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future FBnativeAd() async {
    try {
      var result = await platform.invokeMethod('FBnativeAd');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future showreward() async {
    try {
      var result = await platform.invokeMethod('showreward');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future isEveryads() async {
    try {
      var result = await platform.invokeMethod('isEveryads');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future isBackgroudAds() async {
    try {
      var result = await platform.invokeMethod('isBackgroudAds');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future colors() async {
    try {
      var result = await platform.invokeMethod('colors');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future adManagerIds() async {
    try {
      var result = await platform.invokeMethod('adManagerIds');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future isfacebookads() async {
    try {
      var result = await platform.invokeMethod('isfacebookads');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future isCustomeads() async {
    try {
      var result = await platform.invokeMethod('isCustomeads');
      return result;
    } on PlatformException {
      return '';
    }
  }

  @override
  Future isnativead() async {
    try {
      var result = await platform.invokeMethod('isnativead');
      return result;
    } on PlatformException {
      return '';
    }
  }@override
  Future isrecycleAds() async {
    try {
      var result = await platform.invokeMethod('isrecycleAds');
      return result;
    } on PlatformException {
      return '';
    }
  }
}
